# Generated by Django 5.1.7 on 2025-03-12 16:24

import tinymce.models
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="EmailConfiguration",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "activated",
                    models.BooleanField(
                        default=False,
                        help_text="Só ative essa opção depois de testar as configurações de email no botão ao lado. Quando ativado, as notificações vão ser enviadas por email e será possível a usuários redefinir suas senhas.",
                        verbose_name="Email está ativado?",
                    ),
                ),
                (
                    "host",
                    models.CharField(
                        default="smtp.gmail.com", max_length=128, verbose_name="Host"
                    ),
                ),
                (
                    "port",
                    models.PositiveIntegerField(default=587, verbose_name="Porta"),
                ),
                (
                    "username",
                    models.CharField(
                        default="example@gmail.com",
                        max_length=128,
                        verbose_name="Usuário",
                    ),
                ),
                (
                    "password",
                    models.CharField(
                        default="1234", max_length=128, verbose_name="Senha"
                    ),
                ),
                ("use_tls", models.BooleanField(default=True, verbose_name="Usar TLS")),
                (
                    "use_ssl",
                    models.BooleanField(default=False, verbose_name="Usar SSL"),
                ),
                (
                    "timeout",
                    models.IntegerField(
                        blank=True, default=120, null=True, verbose_name="Timeout"
                    ),
                ),
                (
                    "from_name",
                    models.CharField(
                        blank=True,
                        max_length=255,
                        null=True,
                        verbose_name="Nome do remetente",
                    ),
                ),
                (
                    "from_email",
                    models.EmailField(
                        default="admin@example.com",
                        max_length=254,
                        verbose_name="Email remetente",
                    ),
                ),
                (
                    "signature",
                    tinymce.models.HTMLField(
                        blank=True,
                        help_text="Para usar essa assinatura em seus emails, utilize a variável <code>{{ signature }}</code>.",
                        null=True,
                        verbose_name="Assinatura dos emails",
                    ),
                ),
            ],
            options={
                "verbose_name": "Email configuration",
            },
        ),
    ]
